@@ -33,4 +33,14 @@ impl RelayBoard {
             println!("Invalid relay #:{}!", relay_num);
         }
     }
+
+    pub fn relay_off(&mut self, relay_num: usize) {
+        if relay_num <= self.num_relays && relay_num > 0{
+            println!("Turning relay {} OFF!", relay_num);
+            self.dev_reg_data |= (0x1 << (relay_num - 1));
+            self.bus.smbus_write_byte_data(self.dev_reg_mode1, self.dev_reg_data).unwrap();
+        } else {
+            println!("Invalid relay #:{}!", relay_num);
+        }
+    }
 }
